﻿using System;
using System.Net.Http;
using System.Threading.Tasks;
using System.Xml.Linq;
using System.Linq;
using System.Collections.Generic;

namespace FeedLibrary
{
    //Represent a single content in the RSS feed
    public class FeedItem
    {
        //Properties representing information
        //which is common to any RSS feed
        public string Title { get; set; }
        public string Author { get; set; }
        public string Description { get; set; }
        public DateTimeOffset PubDate { get; set; }
        public Uri Link { get; set; }

        //Return a collection of FeedItem objects from a RSS feed
        public static async Task<IEnumerable<FeedItem>> ParseFeedAsync(string feedUrl)
        {
            var client = new HttpClient();
            //Download the feed content as a string
            var result = await client.GetStringAsync(new Uri(feedUrl));

            //If no result, throw an exception
            if (result == null)
            {
                throw new InvalidOperationException("The specified URL returned a null result");
            }
            else
            {
                //LINQ to XML: Convert the returned string
                //into an XDocument object
                var doc = XDocument.Parse(result);
                var dc = XNamespace.Get("http://purl.org/dc/elements/1.1/");

                //Execute a LINQ query over the XML document
                //and return a collection of FeedItem objects
                var query = (from entry in doc.Descendants("item")
                             select new FeedItem
                             {
                                 Title = entry.Element("title").Value,
                                 Link = new Uri(entry.Element("link").Value),
                                 Author = entry.Element(dc + "creator").Value,
                                 Description = entry.Element("description").Value,
                                 PubDate = DateTimeOffset.Parse(entry.Element("pubDate").Value,
                             System.Globalization.CultureInfo.InvariantCulture)
                             });

                return query;
            }
        }
    }
}

